View Source GoogleApi.ContactCenterInsights.V1.Model.GoogleCloudContactcenterinsightsV1Entity (google_api_contact_center_insights v0.13.0)
The data for an entity annotation. Represents a phrase in the conversation that is a known entity, such as a person, an organization, or location.
Attributes
-
displayName(type:String.t, default:nil) - The representative name for the entity. -
metadata(type:map(), default:nil) - Metadata associated with the entity. For most entity types, the metadata is a Wikipedia URL (wikipedia_url) and Knowledge Graph MID (mid), if they are available. For the metadata associated with other entity types, see the Type table below. -
salience(type:number(), default:nil) - The salience score associated with the entity in the [0, 1.0] range. The salience score for an entity provides information about the importance or centrality of that entity to the entire document text. Scores closer to 0 are less salient, while scores closer to 1.0 are highly salient. -
sentiment(type:GoogleApi.ContactCenterInsights.V1.Model.GoogleCloudContactcenterinsightsV1SentimentData.t, default:nil) - The aggregate sentiment expressed for this entity in the conversation. -
type(type:String.t, default:nil) - The entity type.
Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Types
@type t() :: %GoogleApi.ContactCenterInsights.V1.Model.GoogleCloudContactcenterinsightsV1Entity{ displayName: String.t() | nil, metadata: map() | nil, salience: number() | nil, sentiment: GoogleApi.ContactCenterInsights.V1.Model.GoogleCloudContactcenterinsightsV1SentimentData.t() | nil, type: String.t() | nil }
Functions
Unwrap a decoded JSON object into its complex fields.