View Source GoogleApi.ContactCenterInsights.V1.Model.GoogleCloudContactcenterinsightsV1QaAnswer (google_api_contact_center_insights v0.13.0)
An answer to a QaQuestion.
Attributes
-
answerSources(type:list(GoogleApi.ContactCenterInsights.V1.Model.GoogleCloudContactcenterinsightsV1QaAnswerAnswerSource.t), default:nil) - List of all individual answers given to the question. -
answerValue(type:GoogleApi.ContactCenterInsights.V1.Model.GoogleCloudContactcenterinsightsV1QaAnswerAnswerValue.t, default:nil) - The main answer value, incorporating any manual edits if they exist. -
conversation(type:String.t, default:nil) - The conversation the answer applies to. -
qaQuestion(type:String.t, default:nil) - The QaQuestion answered by this answer. -
questionBody(type:String.t, default:nil) - Question text. E.g., "Did the agent greet the customer?" -
tags(type:list(String.t), default:nil) - User-defined list of arbitrary tags. Matches the value from QaScorecard.ScorecardQuestion.tags. Used for grouping/organization and for weighting the score of each answer.
Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Types
@type t() :: %GoogleApi.ContactCenterInsights.V1.Model.GoogleCloudContactcenterinsightsV1QaAnswer{ answerSources: [ GoogleApi.ContactCenterInsights.V1.Model.GoogleCloudContactcenterinsightsV1QaAnswerAnswerSource.t() ] | nil, answerValue: GoogleApi.ContactCenterInsights.V1.Model.GoogleCloudContactcenterinsightsV1QaAnswerAnswerValue.t() | nil, conversation: String.t() | nil, qaQuestion: String.t() | nil, questionBody: String.t() | nil, tags: [String.t()] | nil }
Functions
Unwrap a decoded JSON object into its complex fields.