View Source GoogleApi.ContactCenterInsights.V1.Model.GoogleCloudContactcenterinsightsV1QaQuestion (google_api_contact_center_insights v0.13.0)
A single question to be scored by the Insights QA feature.
Attributes
-
abbreviation(type:String.t, default:nil) - Short, descriptive string, used in the UI where it's not practical to display the full question body. E.g., "Greeting". -
answerChoices(type:list(GoogleApi.ContactCenterInsights.V1.Model.GoogleCloudContactcenterinsightsV1QaQuestionAnswerChoice.t), default:nil) - A list of valid answers to the question, which the LLM must choose from. -
answerInstructions(type:String.t, default:nil) - Instructions describing how to determine the answer. -
createTime(type:DateTime.t, default:nil) - Output only. The time at which this question was created. -
metrics(type:GoogleApi.ContactCenterInsights.V1.Model.GoogleCloudContactcenterinsightsV1QaQuestionMetrics.t, default:nil) - Metrics of the underlying tuned LLM over a holdout/test set while fine tuning the underlying LLM for the given question. This field will only be populated if and only if the question is part of a scorecard revision that has been tuned. -
name(type:String.t, default:nil) - Identifier. The resource name of the question. Format: projects/{project}/locations/{location}/qaScorecards/{qa_scorecard}/revisions/{revision}/qaQuestions/{qa_question} -
order(type:integer(), default:nil) - Defines the order of the question within its parent scorecard revision. -
questionBody(type:String.t, default:nil) - Question text. E.g., "Did the agent greet the customer?" -
tags(type:list(String.t), default:nil) - User-defined list of arbitrary tags for the question. Used for grouping/organization and for weighting the score of each question. -
tuningMetadata(type:GoogleApi.ContactCenterInsights.V1.Model.GoogleCloudContactcenterinsightsV1QaQuestionTuningMetadata.t, default:nil) - Metadata about the tuning operation for the question.This field will only be populated if and only if the question is part of a scorecard revision that has been tuned. -
updateTime(type:DateTime.t, default:nil) - Output only. The most recent time at which the question was updated.
Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Types
@type t() :: %GoogleApi.ContactCenterInsights.V1.Model.GoogleCloudContactcenterinsightsV1QaQuestion{ abbreviation: String.t() | nil, answerChoices: [ GoogleApi.ContactCenterInsights.V1.Model.GoogleCloudContactcenterinsightsV1QaQuestionAnswerChoice.t() ] | nil, answerInstructions: String.t() | nil, createTime: DateTime.t() | nil, metrics: GoogleApi.ContactCenterInsights.V1.Model.GoogleCloudContactcenterinsightsV1QaQuestionMetrics.t() | nil, name: String.t() | nil, order: integer() | nil, questionBody: String.t() | nil, tags: [String.t()] | nil, tuningMetadata: GoogleApi.ContactCenterInsights.V1.Model.GoogleCloudContactcenterinsightsV1QaQuestionTuningMetadata.t() | nil, updateTime: DateTime.t() | nil }
Functions
Unwrap a decoded JSON object into its complex fields.