View Source GoogleApi.ContactCenterInsights.V1.Model.GoogleCloudContactcenterinsightsV1alpha1Analysis (google_api_contact_center_insights v0.13.0)
The analysis resource.
Attributes
-
analysisResult(type:GoogleApi.ContactCenterInsights.V1.Model.GoogleCloudContactcenterinsightsV1alpha1AnalysisResult.t, default:nil) - Output only. The result of the analysis, which is populated when the analysis finishes. -
annotatorSelector(type:GoogleApi.ContactCenterInsights.V1.Model.GoogleCloudContactcenterinsightsV1alpha1AnnotatorSelector.t, default:nil) - To select the annotators to run and the phrase matchers to use (if any). If not specified, all annotators will be run. -
createTime(type:DateTime.t, default:nil) - Output only. The time at which the analysis was created, which occurs when the long-running operation completes. -
name(type:String.t, default:nil) - Immutable. The resource name of the analysis. Format: projects/{project}/locations/{location}/conversations/{conversation}/analyses/{analysis} -
requestTime(type:DateTime.t, default:nil) - Output only. The time at which the analysis was requested.
Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Types
@type t() :: %GoogleApi.ContactCenterInsights.V1.Model.GoogleCloudContactcenterinsightsV1alpha1Analysis{ analysisResult: GoogleApi.ContactCenterInsights.V1.Model.GoogleCloudContactcenterinsightsV1alpha1AnalysisResult.t() | nil, annotatorSelector: GoogleApi.ContactCenterInsights.V1.Model.GoogleCloudContactcenterinsightsV1alpha1AnnotatorSelector.t() | nil, createTime: DateTime.t() | nil, name: String.t() | nil, requestTime: DateTime.t() | nil }
Functions
Unwrap a decoded JSON object into its complex fields.