View Source GoogleApi.ContactCenterInsights.V1.Model.GoogleCloudContactcenterinsightsV1alpha1AnswerFeedback (google_api_contact_center_insights v0.13.0)
The feedback that the customer has about a certain answer in the conversation.
Attributes
-
clicked(type:boolean(), default:nil) - Indicates whether an answer or item was clicked by the human agent. -
correctnessLevel(type:String.t, default:nil) - The correctness level of an answer. -
displayed(type:boolean(), default:nil) - Indicates whether an answer or item was displayed to the human agent in the agent desktop UI.
Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Types
Functions
Unwrap a decoded JSON object into its complex fields.