View Source GoogleApi.ContactCenterInsights.V1.Model.GoogleCloudContactcenterinsightsV1alpha1ExportInsightsDataRequest (google_api_contact_center_insights v0.13.0)
The request to export insights.
Attributes
-
bigQueryDestination(type:GoogleApi.ContactCenterInsights.V1.Model.GoogleCloudContactcenterinsightsV1alpha1ExportInsightsDataRequestBigQueryDestination.t, default:nil) - Specified if sink is a BigQuery table. -
filter(type:String.t, default:nil) - A filter to reduce results to a specific subset. Useful for exporting conversations with specific properties. -
kmsKey(type:String.t, default:nil) - A fully qualified KMS key name for BigQuery tables protected by CMEK. Format: projects/{project}/locations/{location}/keyRings/{keyring}/cryptoKeys/{key}/cryptoKeyVersions/{version} -
parent(type:String.t, default:nil) - Required. The parent resource to export data from. -
writeDisposition(type:String.t, default:nil) - Options for what to do if the destination table already exists.
Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Types
@type t() :: %GoogleApi.ContactCenterInsights.V1.Model.GoogleCloudContactcenterinsightsV1alpha1ExportInsightsDataRequest{ bigQueryDestination: GoogleApi.ContactCenterInsights.V1.Model.GoogleCloudContactcenterinsightsV1alpha1ExportInsightsDataRequestBigQueryDestination.t() | nil, filter: String.t() | nil, kmsKey: String.t() | nil, parent: String.t() | nil, writeDisposition: String.t() | nil }
Functions
Unwrap a decoded JSON object into its complex fields.