View Source GoogleApi.ContactCenterInsights.V1.Model.GoogleCloudContactcenterinsightsV1alpha1FaqAnswerData (google_api_contact_center_insights v0.13.0)
Agent Assist frequently-asked-question answer data.
Attributes
-
answer(type:String.t, default:nil) - The piece of text from thesourceknowledge base document. -
confidenceScore(type:number(), default:nil) - The system's confidence score that this answer is a good match for this conversation, ranging from 0.0 (completely uncertain) to 1.0 (completely certain). -
metadata(type:map(), default:nil) - Map that contains metadata about the FAQ answer and the document that it originates from. -
queryRecord(type:String.t, default:nil) - The name of the answer record. Format: projects/{project}/locations/{location}/answerRecords/{answer_record} -
question(type:String.t, default:nil) - The corresponding FAQ question. -
source(type:String.t, default:nil) - The knowledge document that this answer was extracted from. Format: projects/{project}/knowledgeBases/{knowledge_base}/documents/{document}.
Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Types
Functions
Unwrap a decoded JSON object into its complex fields.